@@ -137,6 +137,9 @@ void fill_mem(char *ptr, FILE *fp) {
 #ifdef NESSUS_PLUGIN    
     char * svc_kb_name;
     char * asc_port;
+#ifdef NEW_KB_MGMT
+    int type;
+#endif
 #endif  
     char empty_login[2];
     
@@ -353,9 +356,21 @@ void fill_mem(char *ptr, FILE *fp) {
       strcpy(svc_kb_name, "Services/www");
     else
       sprintf(svc_kb_name, "Services/%s", service);
+
+#ifdef NEW_KB_MGMT
+    asc_port = plug_get_key(nessus, svc_kb_name, &type);
+    if ( asc_port != NULL )
+    {
+	if ( type == KB_TYPE_STR ) port = atoi(asc_port);
+	else port = (int)asc_port;
+    }
+#else
     asc_port = plug_get_key(nessus, svc_kb_name);
     if (asc_port)port = atoi(asc_port);
-    else if(asc_port == NULL )
+#endif
+
+
+    if(asc_port == NULL )
     {
      if(strcmp(svc_kb_name, "Services/www") == 0 )
      	port = 80;
